/**
 * BaseDialog
 *
 * The BaseDialog component provides a structured Modal, containing
 * a fixed header and footer section, and a scrollable body section
 * that can expand/contract based on the content size.
 *
 * The header/footer are styled depending on the scroll state to
 * indicated start/end of scrolling.
 *
 * By filling the header/footer and content, you can build up more
 * specific dialogs. All dialogs should follow this structure.
 */
import { FC } from 'react';
import { ModalProps } from '../Modal';
export declare type DialogWidth = 'normal' | 'settings-panel' | 'large-settings-panel';
export declare const DialogHeader: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
export declare const DialogContent: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
export declare const DialogFooter: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
interface BaseDialogContentProps {
    /**
     * The width of the dialog, one of `'normal'`, `'settings-panel'` or
     * `'large-settings-panel'`.
     *
     * Default: `'normal'`
     */
    readonly width?: DialogWidth;
}
export declare type BaseDialogProps = BaseDialogContentProps & ModalProps;
export declare const BaseDialog: FC<BaseDialogProps>;
export {};
