import { LiHTMLAttributes, FC } from 'react';
declare type BaseElement = HTMLUListElement;
declare type BaseProps = LiHTMLAttributes<BaseElement>;
export interface SelectListItemOption {
    /**
     * Value of the option
     */
    readonly value: string;
    /**
     * Label that is shown to the user in the SelectList component
     */
    readonly label: string;
    /**
     * Disables the value, restricts the user from selecting it
     */
    readonly disabled?: boolean;
}
export interface SelectListProps extends Omit<BaseProps, 'onSelect'> {
    /**
     * Current value that is selected.
     */
    readonly value: string;
    /**
     * Options to be displayed in the SelectList component.
     */
    readonly options: ReadonlyArray<SelectListItemOption>;
    /**
     * Set state action, returns new selected value.
     */
    readonly onSelect: (value: string) => void;
    /**
     * Sets the css property maxHeight as px.
     * Default: `320`
     */
    readonly maxHeight?: number;
}
/**
 * SelectList
 *
 * Is a scrollable list that a user may select one value from,
 * the selected value is highlighted.
 *
 * It differs from the normal Select component in the sense
 * that there is no button to open/close the list of options,
 * in SelectList the options is always visible to the user.
 *
 */
export declare const SelectList: FC<SelectListProps>;
export {};
